==> kdepim-addons-19.03.90.tar.xz: kdepim-addons-19.03.90/kaddressbook/plugins/searchduplicates/searchduplicatesplugininterface.h <==
/*
   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef SEARCHDUPLICATESPLUGININTERFACE_H
#define SEARCHDUPLICATESPLUGININTERFACE_H

#include <PimCommonAkonadi/GenericPluginInterface>

class SearchDuplicatesPluginInterface : public PimCommon::GenericPluginInterface
{
public:
    explicit SearchDuplicatesPluginInterface(QObject *parent = nullptr);
    ~SearchDuplicatesPluginInterface() override;

    void exec() override;
    void createAction(KActionCollection *ac) override;
    PimCommon::GenericPluginInterface::RequireTypes requires() const override;
    void setItems(const Akonadi::Item::List &items) override;

private:
    void slotActivated();
    Akonadi::Item::List mListItems;
};

#endif // SEARCHDUPLICATESPLUGININTERFACE_H

==> kdepim-addons-20.07.90.tar.xz: kdepim-addons-20.07.90/kaddressbook/plugins/searchduplicates/searchduplicatesplugininterface.h <==
/*
   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef SEARCHDUPLICATESPLUGININTERFACE_H
#define SEARCHDUPLICATESPLUGININTERFACE_H

#include <PimCommonAkonadi/GenericPluginInterface>

class SearchDuplicatesPluginInterface : public PimCommon::GenericPluginInterface
{
public:
    explicit SearchDuplicatesPluginInterface(QObject *parent = nullptr);
    ~SearchDuplicatesPluginInterface() override;

    void exec() override;
    void createAction(KActionCollection *ac) override;
    Q_REQUIRED_RESULT PimCommon::GenericPluginInterface::RequireTypes requires() const override;
    void setItems(const Akonadi::Item::List &items) override;

private:
    void slotActivated();
    Akonadi::Item::List mListItems;
};

#endif // SEARCHDUPLICATESPLUGININTERFACE_H
